package com.gic.haoban.manage.web.controller;


import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.app.customer.dto.MessageLogDTO;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.base.api.common.PageResult2;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.manage.api.dto.AuditDTO;
import com.gic.haoban.manage.api.service.AuditApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.AuditVO;


@RestController
public class AuditController extends WebBaseController{
	
	private static Logger logger= LoggerFactory.getLogger(AuditController.class);
	
	@Autowired
	private AuditApiService auditApiService;
	
	@RequestMapping("clerk-apply-list")
	public HaobanResponse staffStoreList(String staffId,String wxEnterpriseId,BasePageInfo pageInfo){
		if(StringUtils.isAnyBlank(staffId,wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		
		Page<AuditDTO> page = auditApiService.listByStaffId(staffId,pageInfo);
		List<AuditDTO> list = page.getResult();
		List<AuditVO> voList = new ArrayList<AuditVO>();
		for (AuditDTO auditDTO : list) {
			AuditVO vo = EntityUtil.changeEntityByJSON(AuditVO.class, auditDTO);
			String clerkCode = "";
			String staffName = "";
			String oldValue = auditDTO.getOldValue();
			JSONObject json = JSON.parseObject(oldValue);
			clerkCode = json.getString("clerkCode");
			staffName = json.getString("staffName");
			if(auditDTO.getAuditType() == 3){
				vo.setCommitReason("添加导购账号：("+clerkCode+")");
			}else if(auditDTO.getAuditType() == 4){
				vo.setCommitReason("删除导购账号：("+clerkCode+")");
			}else{
				vo.setCommitReason("绑定申请{"+staffName+"}绑定登录导购code "+clerkCode);
			}
			voList.add(vo);
		}
		Page<AuditVO> pageVO = new Page<>();
		pageVO.setCurrentPage(page.getCurrentPage());
		pageVO.setPageSize(page.getPageSize());
		pageVO.setResult(voList);
		pageVO.setTotalCount(page.getTotalCount());
		pageVO.setTotalPage(page.getTotalPage());
		PageResult2 pageResult2 = PageUtil.getPageInfo(pageVO);
		return resultResponse(HaoBanErrCode.ERR_1,pageResult2);
		
	}
	
	@RequestMapping("store-apply-list")
	public HaobanResponse storeApplyList(String storeId,String wxEnterpriseId,BasePageInfo pageInfo,Integer auditType,Integer auditStatus){
		if(StringUtils.isAnyBlank(storeId,wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		
		Page<AuditDTO> page = auditApiService.pageStoreListByParams(storeId,pageInfo,auditType,auditStatus);
		List<AuditDTO> list = page.getResult();
		List<AuditVO> voList = new ArrayList<AuditVO>();
		for (AuditDTO auditDTO : list) {
			AuditVO vo = EntityUtil.changeEntityByJSON(AuditVO.class, auditDTO);
			String clerkCode = "";
			String staffName = "";
			String oldValue = auditDTO.getOldValue();
			JSONObject json = JSON.parseObject(oldValue);
			clerkCode = json.getString("clerkCode");
			staffName = json.getString("staffName");
			if(auditDTO.getAuditType() == 3){
				vo.setCommitReason("添加导购账号：("+clerkCode+")");
			}else if(auditDTO.getAuditType() == 4){
				vo.setCommitReason("删除导购账号：("+clerkCode+")");
			}else if(auditDTO.getAuditType() == 5){
				vo.setCommitReason("解除绑定：("+clerkCode+")");
			}else{
				vo.setCommitReason("绑定申请{"+staffName+"}绑定登录导购code "+clerkCode);
			}
			voList.add(vo);
		}
		Page<AuditVO> pageVO = new Page<>();
		pageVO.setCurrentPage(page.getCurrentPage());
		pageVO.setPageSize(page.getPageSize());
		pageVO.setResult(voList);
		pageVO.setTotalCount(page.getTotalCount());
		pageVO.setTotalPage(page.getTotalPage());
		PageResult2 pageResult2 = PageUtil.getPageInfo(pageVO);
		return resultResponse(HaoBanErrCode.ERR_1,pageResult2);
		
	}

}
